@@ -1,18 +1,17 @@
-# -*- coding: utf-8 -*-
-
-from .callbacks_mixin import BlueprintCallBacksMixin
+from .mixins import RoutesMixin, BlueprintEventsMixin
 
 
-class Blueprint(BlueprintCallBacksMixin):
+class Blueprint(RoutesMixin, BlueprintEventsMixin):
 
     name = None
     app = None
 
-    def __init__(self, name=None):
-        super(Blueprint, self).__init__()
+    def __init__(self, name):
+        RoutesMixin.__init__(self)
+        BlueprintEventsMixin.__init__(self)
         self.name = name
 
-    def register2app(self, app):
+    def register_to_app(self, app):
         """
         注册到app上
         """
